/* DO NOT EDIT THIS FILE - it is machine generated */
#include <jni.h>
/* Header for class ptutils */

#ifndef _Included_ptutils
#define _Included_ptutils
#ifdef __cplusplus
extern "C" {
#endif
#undef ptutils__initProgress
#define ptutils__initProgress 0L
#undef ptutils__setProgress
#define ptutils__setProgress 1L
#undef ptutils__disposeProgress
#define ptutils__disposeProgress 2L
#undef ptutils__idleProgress
#define ptutils__idleProgress 3L
/* Inaccessible static: pr */
/* Inaccessible static: pi */
/* Inaccessible static: BicCoeff */
/*
 * Class:     ptutils
 * Method:    CAlignPoint
 * Signature: ([D[I[I)V
 */
JNIEXPORT void JNICALL Java_ptutils_CAlignPoint
  (JNIEnv *, jobject, jdoubleArray, jintArray, jintArray);

/*
 * Class:     ptutils
 * Method:    CSaveProject
 * Signature: (Ljava/lang/String;)V
 */
JNIEXPORT void JNICALL Java_ptutils_CSaveProject
  (JNIEnv *, jobject, jstring);

/*
 * Class:     ptutils
 * Method:    CSetControlPointCount
 * Signature: (I)V
 */
JNIEXPORT void JNICALL Java_ptutils_CSetControlPointCount
  (JNIEnv *, jobject, jint);

/*
 * Class:     ptutils
 * Method:    CSetCP
 * Signature: (IIIDDDDI)V
 */
JNIEXPORT void JNICALL Java_ptutils_CSetCP
  (JNIEnv *, jobject, jint, jint, jint, jdouble, jdouble, jdouble, jdouble, jint);

/*
 * Class:     ptutils
 * Method:    CSetTriangleCount
 * Signature: (I)V
 */
JNIEXPORT void JNICALL Java_ptutils_CSetTriangleCount
  (JNIEnv *, jobject, jint);

/*
 * Class:     ptutils
 * Method:    CSetTR
 * Signature: (IIIII)V
 */
JNIEXPORT void JNICALL Java_ptutils_CSetTR
  (JNIEnv *, jobject, jint, jint, jint, jint, jint);

/*
 * Class:     ptutils
 * Method:    CLoadProject
 * Signature: (Ljava/lang/String;)V
 */
JNIEXPORT void JNICALL Java_ptutils_CLoadProject
  (JNIEnv *, jobject, jstring);

/*
 * Class:     ptutils
 * Method:    CGetImageCount
 * Signature: ()I
 */
JNIEXPORT jint JNICALL Java_ptutils_CGetImageCount
  (JNIEnv *, jobject);

/*
 * Class:     ptutils
 * Method:    CGetImageName
 * Signature: (I)Ljava/lang/String;
 */
JNIEXPORT jstring JNICALL Java_ptutils_CGetImageName
  (JNIEnv *, jobject, jint);

/*
 * Class:     ptutils
 * Method:    CGetControlPointCount
 * Signature: ()I
 */
JNIEXPORT jint JNICALL Java_ptutils_CGetControlPointCount
  (JNIEnv *, jobject);

/*
 * Class:     ptutils
 * Method:    CGetCP_n
 * Signature: (II)I
 */
JNIEXPORT jint JNICALL Java_ptutils_CGetCP_1n
  (JNIEnv *, jobject, jint, jint);

/*
 * Class:     ptutils
 * Method:    CGetCP_x
 * Signature: (II)D
 */
JNIEXPORT jdouble JNICALL Java_ptutils_CGetCP_1x
  (JNIEnv *, jobject, jint, jint);

/*
 * Class:     ptutils
 * Method:    CGetCP_y
 * Signature: (II)D
 */
JNIEXPORT jdouble JNICALL Java_ptutils_CGetCP_1y
  (JNIEnv *, jobject, jint, jint);

/*
 * Class:     ptutils
 * Method:    CGetCP_t
 * Signature: (I)I
 */
JNIEXPORT jint JNICALL Java_ptutils_CGetCP_1t
  (JNIEnv *, jobject, jint);

/*
 * Class:     ptutils
 * Method:    CGetTriangleCount
 * Signature: ()I
 */
JNIEXPORT jint JNICALL Java_ptutils_CGetTriangleCount
  (JNIEnv *, jobject);

/*
 * Class:     ptutils
 * Method:    CGetTR_v
 * Signature: (II)I
 */
JNIEXPORT jint JNICALL Java_ptutils_CGetTR_1v
  (JNIEnv *, jobject, jint, jint);

/*
 * Class:     ptutils
 * Method:    CGetTR_i
 * Signature: (I)I
 */
JNIEXPORT jint JNICALL Java_ptutils_CGetTR_1i
  (JNIEnv *, jobject, jint);

/*
 * Class:     ptutils
 * Method:    CSetImageName
 * Signature: (ILjava/lang/String;)V
 */
JNIEXPORT void JNICALL Java_ptutils_CSetImageName
  (JNIEnv *, jobject, jint, jstring);

/*
 * Class:     ptutils
 * Method:    CGetIndex
 * Signature: (Ljava/lang/String;)I
 */
JNIEXPORT jint JNICALL Java_ptutils_CGetIndex
  (JNIEnv *, jobject, jstring);

/*
 * Class:     ptutils
 * Method:    CLoadImage
 * Signature: (I)V
 */
JNIEXPORT void JNICALL Java_ptutils_CLoadImage
  (JNIEnv *, jobject, jint);

/*
 * Class:     ptutils
 * Method:    CGetImageRow
 * Signature: ([II)V
 */
JNIEXPORT void JNICALL Java_ptutils_CGetImageRow
  (JNIEnv *, jobject, jintArray, jint);

/*
 * Class:     ptutils
 * Method:    CGetImageWidth
 * Signature: (I)I
 */
JNIEXPORT jint JNICALL Java_ptutils_CGetImageWidth
  (JNIEnv *, jobject, jint);

/*
 * Class:     ptutils
 * Method:    CGetImageHeight
 * Signature: (I)I
 */
JNIEXPORT jint JNICALL Java_ptutils_CGetImageHeight
  (JNIEnv *, jobject, jint);

/*
 * Class:     ptutils
 * Method:    CCreateProject
 * Signature: (Ljava/lang/String;ILjava/lang/String;IID)V
 */
JNIEXPORT void JNICALL Java_ptutils_CCreateProject
  (JNIEnv *, jobject, jstring, jint, jstring, jint, jint, jdouble);

/*
 * Class:     ptutils
 * Method:    CTriangulate
 * Signature: (I)V
 */
JNIEXPORT void JNICALL Java_ptutils_CTriangulate
  (JNIEnv *, jobject, jint);

/*
 * Class:     ptutils
 * Method:    CReduce
 * Signature: (I)V
 */
JNIEXPORT void JNICALL Java_ptutils_CReduce
  (JNIEnv *, jobject, jint);

/*
 * Class:     ptutils
 * Method:    CCallOptimizer
 * Signature: ()V
 */
JNIEXPORT void JNICALL Java_ptutils_CCallOptimizer
  (JNIEnv *, jobject);

/*
 * Class:     ptutils
 * Method:    CShowScript
 * Signature: ()V
 */
JNIEXPORT void JNICALL Java_ptutils_CShowScript
  (JNIEnv *, jobject);

/*
 * Class:     ptutils
 * Method:    CLaunchAndSendScript
 * Signature: (Ljava/lang/String;Ljava/lang/String;)V
 */
JNIEXPORT void JNICALL Java_ptutils_CLaunchAndSendScript
  (JNIEnv *, jobject, jstring, jstring);

/*
 * Class:     ptutils
 * Method:    CGetImageFormat
 * Signature: (I)I
 */
JNIEXPORT jint JNICALL Java_ptutils_CGetImageFormat
  (JNIEnv *, jobject, jint);

/*
 * Class:     ptutils
 * Method:    CGetHfov
 * Signature: (I)D
 */
JNIEXPORT jdouble JNICALL Java_ptutils_CGetHfov
  (JNIEnv *, jobject, jint);

/*
 * Class:     ptutils
 * Method:    CGetYaw
 * Signature: (I)D
 */
JNIEXPORT jdouble JNICALL Java_ptutils_CGetYaw
  (JNIEnv *, jobject, jint);

/*
 * Class:     ptutils
 * Method:    CGetPitch
 * Signature: (I)D
 */
JNIEXPORT jdouble JNICALL Java_ptutils_CGetPitch
  (JNIEnv *, jobject, jint);

/*
 * Class:     ptutils
 * Method:    CGetRoll
 * Signature: (I)D
 */
JNIEXPORT jdouble JNICALL Java_ptutils_CGetRoll
  (JNIEnv *, jobject, jint);

#ifdef __cplusplus
}
#endif
#endif
