/* DO NOT EDIT THIS FILE - it is machine generated */
#include <jni.h>
/* Header for class pteditor */

#ifndef _Included_pteditor
#define _Included_pteditor
#ifdef __cplusplus
extern "C" {
#endif
/* Inaccessible static: LOCK */
/* Inaccessible static: dbg */
/* Inaccessible static: isInc */
/* Inaccessible static: incRate */
#undef pteditor_TOP_ALIGNMENT
#define pteditor_TOP_ALIGNMENT 0.0f
#undef pteditor_CENTER_ALIGNMENT
#define pteditor_CENTER_ALIGNMENT 0.5f
#undef pteditor_BOTTOM_ALIGNMENT
#define pteditor_BOTTOM_ALIGNMENT 1.0f
#undef pteditor_LEFT_ALIGNMENT
#define pteditor_LEFT_ALIGNMENT 0.0f
#undef pteditor_RIGHT_ALIGNMENT
#define pteditor_RIGHT_ALIGNMENT 1.0f
#undef pteditor_serialVersionUID
#define pteditor_serialVersionUID -7644114512714619750LL
/* Inaccessible static: metrics */
/* Inaccessible static: class_00024java_00024awt_00024Component */
/* Inaccessible static: class_00024java_00024awt_00024event_00024ComponentListener */
/* Inaccessible static: class_00024java_00024awt_00024event_00024FocusListener */
/* Inaccessible static: class_00024java_00024awt_00024event_00024HierarchyListener */
/* Inaccessible static: class_00024java_00024awt_00024event_00024HierarchyBoundsListener */
/* Inaccessible static: class_00024java_00024awt_00024event_00024KeyListener */
/* Inaccessible static: class_00024java_00024awt_00024event_00024MouseListener */
/* Inaccessible static: class_00024java_00024awt_00024event_00024MouseMotionListener */
/* Inaccessible static: class_00024java_00024awt_00024event_00024InputMethodListener */
#undef pteditor_serialVersionUID
#define pteditor_serialVersionUID 4613797578919906343LL
/* Inaccessible static: dbg */
/* Inaccessible static: class_00024java_00024awt_00024Container */
/* Inaccessible static: class_00024java_00024awt_00024event_00024ContainerListener */
#undef pteditor_OPENED
#define pteditor_OPENED 1L
/* Inaccessible static: nameCounter */
#undef pteditor_serialVersionUID
#define pteditor_serialVersionUID 4497834738069338734LL
/* Inaccessible static: dbg */
/* Inaccessible static: class_00024java_00024awt_00024Container */
/* Inaccessible static: class_00024java_00024awt_00024event_00024WindowListener */
#undef pteditor_DEFAULT_CURSOR
#define pteditor_DEFAULT_CURSOR 0L
#undef pteditor_CROSSHAIR_CURSOR
#define pteditor_CROSSHAIR_CURSOR 1L
#undef pteditor_TEXT_CURSOR
#define pteditor_TEXT_CURSOR 2L
#undef pteditor_WAIT_CURSOR
#define pteditor_WAIT_CURSOR 3L
#undef pteditor_SW_RESIZE_CURSOR
#define pteditor_SW_RESIZE_CURSOR 4L
#undef pteditor_SE_RESIZE_CURSOR
#define pteditor_SE_RESIZE_CURSOR 5L
#undef pteditor_NW_RESIZE_CURSOR
#define pteditor_NW_RESIZE_CURSOR 6L
#undef pteditor_NE_RESIZE_CURSOR
#define pteditor_NE_RESIZE_CURSOR 7L
#undef pteditor_N_RESIZE_CURSOR
#define pteditor_N_RESIZE_CURSOR 8L
#undef pteditor_S_RESIZE_CURSOR
#define pteditor_S_RESIZE_CURSOR 9L
#undef pteditor_W_RESIZE_CURSOR
#define pteditor_W_RESIZE_CURSOR 10L
#undef pteditor_E_RESIZE_CURSOR
#define pteditor_E_RESIZE_CURSOR 11L
#undef pteditor_HAND_CURSOR
#define pteditor_HAND_CURSOR 12L
#undef pteditor_MOVE_CURSOR
#define pteditor_MOVE_CURSOR 13L
#undef pteditor_NORMAL
#define pteditor_NORMAL 0L
#undef pteditor_ICONIFIED
#define pteditor_ICONIFIED 1L
/* Inaccessible static: nameCounter */
#undef pteditor_serialVersionUID
#define pteditor_serialVersionUID 2673458971256075116LL
/* Inaccessible static: class_00024java_00024awt_00024Frame */
/* Inaccessible static: PTViewer */
#undef pteditor__equirectangular
#define pteditor__equirectangular 4L
/*
 * Class:     pteditor
 * Method:    CLoadImage
 * Signature: (Ljava/lang/String;)V
 */
JNIEXPORT void JNICALL Java_pteditor_CLoadImage
  (JNIEnv *, jobject, jstring);

/*
 * Class:     pteditor
 * Method:    CSaveImage
 * Signature: (Ljava/lang/String;)V
 */
JNIEXPORT void JNICALL Java_pteditor_CSaveImage
  (JNIEnv *, jobject, jstring);

/*
 * Class:     pteditor
 * Method:    CGetImageWidth
 * Signature: ()I
 */
JNIEXPORT jint JNICALL Java_pteditor_CGetImageWidth
  (JNIEnv *, jobject);

/*
 * Class:     pteditor
 * Method:    CGetImageHeight
 * Signature: ()I
 */
JNIEXPORT jint JNICALL Java_pteditor_CGetImageHeight
  (JNIEnv *, jobject);

/*
 * Class:     pteditor
 * Method:    CGetImageRow
 * Signature: ([II)V
 */
JNIEXPORT void JNICALL Java_pteditor_CGetImageRow
  (JNIEnv *, jobject, jintArray, jint);

/*
 * Class:     pteditor
 * Method:    CExtract
 * Signature: (Ljava/lang/String;DDDDID)V
 */
JNIEXPORT void JNICALL Java_pteditor_CExtract
  (JNIEnv *, jobject, jstring, jdouble, jdouble, jdouble, jdouble, jint, jdouble);

/*
 * Class:     pteditor
 * Method:    CInsert
 * Signature: (Ljava/lang/String;DDDDI)V
 */
JNIEXPORT void JNICALL Java_pteditor_CInsert
  (JNIEnv *, jobject, jstring, jdouble, jdouble, jdouble, jdouble, jint);

/*
 * Class:     pteditor
 * Method:    CSetImageWidth
 * Signature: (I)V
 */
JNIEXPORT void JNICALL Java_pteditor_CSetImageWidth
  (JNIEnv *, jobject, jint);

/*
 * Class:     pteditor
 * Method:    CSetImageHeight
 * Signature: (I)V
 */
JNIEXPORT void JNICALL Java_pteditor_CSetImageHeight
  (JNIEnv *, jobject, jint);

/*
 * Class:     pteditor
 * Method:    CSetImageRow
 * Signature: ([II)V
 */
JNIEXPORT void JNICALL Java_pteditor_CSetImageRow
  (JNIEnv *, jobject, jintArray, jint);

#ifdef __cplusplus
}
#endif
#endif
